@@ -3,9 +3,11 @@
 #' @name mlr_learners_clust.cmeans
 #'
 #' @description
-#' A [LearnerClust] for fuzzy clustering implemented in [e1071::cmeans()].
-#' [e1071::cmeans()] doesn't have a default value for the number of clusters.
-#' Therefore, the `centers` parameter here is set to 2 by default.
+#' Fuzzy c-means clustering.
+#' Calls [e1071::cmeans()] from package \CRANpkg{e1071}.
+#'
+#' The `centers` parameter is set to 2 by default since [e1071::cmeans()]
+#' doesn't have a default value for the number of clusters.
 #' The predict method uses [clue::cl_predict()] to compute the
 #' cluster memberships for new data.
 #'
@@ -50,9 +52,9 @@ LearnerClustCMeans = R6Class("LearnerClustCMeans",
         predict_types = c("partition", "prob"),
         param_set = param_set,
         properties = c("partitional", "fuzzy", "complete"),
-        packages = "e1071",
+        packages = c("e1071", "clue"),
         man = "mlr3cluster::mlr_learners_clust.cmeans",
-        label = "Fuzzy C-Means Clustering Learner"
+        label = "Fuzzy C-Means"
       )
     }
   ),
@@ -70,10 +72,12 @@ LearnerClustCMeans = R6Class("LearnerClustCMeans",
     },
 
     .predict = function(task) {
-      partition = unclass(invoke(cl_predict, self$model, newdata = task$data(), type = "class_ids"))
-      prob = unclass(invoke(cl_predict, self$model, newdata = task$data(), type = "memberships"))
-      colnames(prob) = seq_len(ncol(prob))
-
+      partition = unclass(invoke(clue::cl_predict, self$model, newdata = task$data(), type = "class_ids"))
+      prob = NULL
+      if (self$predict_type == "prob") {
+        prob = unclass(invoke(clue::cl_predict, self$model, newdata = task$data(), type = "memberships"))
+        colnames(prob) = seq_len(ncol(prob))
+      }
       PredictionClust$new(task = task, partition = partition, prob = prob)
     }
   )
