@@ -3,13 +3,13 @@
 #' @name mlr_learners_clust.fanny
 #'
 #' @description
-#' A [LearnerClust] for fuzzy clustering implemented in [cluster::fanny()].
-#' [cluster::fanny()] doesn't have a default value for the number of clusters.
-#' Therefore, the `k` parameter which corresponds to the number
-#' of clusters here is set to 2 by default.
+#' Fuzzy Analysis (FANNY) clustering.
+#' Calls [cluster::fanny()] from package \CRANpkg{cluster}.
+#'
+#' The `k` parameter is set to 2 by default since [cluster::fanny()]
+#' doesn't have a default value for the number of clusters.
 #' The predict method copies cluster assignments and memberships
-#' generated for train data. The predict does not work for
-#' new data.
+#' generated for train data. The predict does not work for new data.
 #'
 #' @templateVar id clust.fanny
 #' @template learner
@@ -31,6 +31,11 @@ LearnerClustFanny = R6Class("LearnerClustFanny",
         memb.exp = p_dbl(1, default = 2, tags = "train"),
         metric = p_fct(c("euclidean", "manhattan", "SqEuclidean"), default = "euclidean", tags = "train"),
         stand = p_lgl(default = FALSE, tags = "train"),
+        iniMem.p = p_uty(
+          default = NULL,
+          tags = "train",
+          custom_check = crate(function(x) check_matrix(x, mode = "numeric", null.ok = TRUE))
+        ),
         maxit = p_int(0L, default = 500L, tags = "train"),
         tol = p_dbl(0, default = 1e-15, tags = "train"),
         trace.lev = p_int(0L, default = 0L, tags = "train")
@@ -46,7 +51,7 @@ LearnerClustFanny = R6Class("LearnerClustFanny",
         properties = c("partitional", "fuzzy", "complete"),
         packages = "cluster",
         man = "mlr3cluster::mlr_learners_clust.fanny",
-        label = "Fuzzy Analysis Clustering"
+        label = "Fuzzy Analysis"
       )
     }
   ),
@@ -63,12 +68,12 @@ LearnerClustFanny = R6Class("LearnerClustFanny",
 
     .predict = function(task) {
       warn_prediction_useless(self$id)
-
       partition = self$model$clustering
-
-      prob = self$model$membership
-      colnames(prob) = seq_len(ncol(prob))
-
+      prob = NULL
+      if (self$predict_type == "prob") {
+        prob = self$model$membership
+        colnames(prob) = seq_len(ncol(prob))
+      }
       PredictionClust$new(task = task, partition = partition, prob = prob)
     }
   )
