@@ -1,9 +1,11 @@
-#' @title Gaussian Mixture Models-Based Clustering Learner
+#' @title Gaussian Mixture Model Clustering Learner
 #'
 #' @name mlr_learners_clust.mclust
 #'
 #' @description
-#' A [LearnerClust] for model-based clustering implemented in [mclust::Mclust()].
+#' Gaussian mixture model-based clustering.
+#' Calls [mclust::Mclust()] from package \CRANpkg{mclust}.
+#'
 #' The predict method uses [mclust::predict.Mclust()] to compute the
 #' cluster memberships for new data.
 #'
@@ -22,24 +24,28 @@ LearnerClustMclust = R6Class("LearnerClustMclust",
     #' @description
     #' Creates a new instance of this [R6][R6::R6Class] class.
     initialize = function() {
-      parma_set = ps(
+      param_set = ps(
         G = p_uty(default = 1:9, tags = "train", custom_check = check_numeric),
         modelNames = p_uty(tags = "train", custom_check = check_character),
         prior = p_uty(tags = "train", custom_check = check_list),
         control = p_uty(tags = "train", custom_check = check_list),
         initialization = p_uty(tags = "train", custom_check = check_list),
-        x = p_uty(tags = "train", custom_check = crate(function(x) check_class(x, "mclustBIC")))
+        warn = p_lgl(default = FALSE, tags = "train"),
+        x = p_uty(tags = "train", custom_check = crate(function(x) check_class(x, "mclustBIC"))),
+        verbose = p_lgl(default = FALSE, tags = "train")
       )
 
+      param_set$set_values(warn = FALSE, verbose = FALSE)
+
       super$initialize(
         id = "clust.mclust",
         feature_types = c("logical", "integer", "numeric"),
         predict_types = c("partition", "prob"),
-        param_set = parma_set,
+        param_set = param_set,
         properties = c("partitional", "fuzzy", "complete"),
         packages = "mclust",
         man = "mlr3cluster::mlr_learners_clust.mclust",
-        label = "Gaussian Mixture Models Clustering"
+        label = "Gaussian Mixture Model"
       )
     }
   ),
@@ -59,7 +65,10 @@ LearnerClustMclust = R6Class("LearnerClustMclust",
     .predict = function(task) {
       predictions = invoke(predict, self$model, newdata = task$data())
       partition = as.integer(predictions$classification)
-      prob = predictions$z
+      prob = NULL
+      if (self$predict_type == "prob") {
+        prob = predictions$z
+      }
       PredictionClust$new(task = task, partition = partition, prob = prob)
     }
   )
