@@ -50,13 +50,13 @@ as_prediction_clust.data.frame = function(x, ...) { # nolint
 
   if (length(prob_cols) > 0L) {
     if (!all(startsWith(prob_cols, "prob."))) {
-      stopf(
+      error_input(
         "Table may only contain columns 'row_ids', 'partition' as well as columns prefixed with 'prob.' for class probabilities." # nolint
       )
     }
     prob = as.matrix(x[, prob_cols, with = FALSE])
-    nms = colnames(prob)
-    colnames(prob) = substr(nms, 6L, nchar(nms))
+    cn = colnames(prob)
+    colnames(prob) = substr(cn, 6L, nchar(cn))
   } else {
     prob = NULL
   }
