@@ -8,7 +8,7 @@ test_that("Cluster measures", {
     m = mlr_measures$get(key)
     if (m$task_type == "clust") {
       perf = m$score(prediction = p, task = task, learner = learner)
-      expect_number(perf, na.ok = FALSE, lower = m$range[1], upper = m$range[2])
+      expect_number(perf, na.ok = FALSE, lower = m$range[1L], upper = m$range[2L])
     }
   }
 })
