@@ -1,12 +1,10 @@
-skip_if_not_installed("clue")
-
 test_that("autotest", {
   learner = lrn("clust.agnes")
   expect_learner(learner)
   task = generate_tasks(learner)
-  learner$train(task[[1]])
+  learner$train(task[[1L]])
   expect_class(learner$model, "agnes")
-  expect_warning(learner$predict(task[[1]]), "doesn't predict on new data")
+  expect_warning(learner$predict(task[[1L]]), "doesn't predict on new data")
 })
 
 test_that("Learner properties are respected", {
@@ -22,8 +20,7 @@ test_that("Learner properties are respected", {
     list(k = 2L, stand = TRUE)
   )
 
-  for (i in seq_along(parset_list)) {
-    parset = parset_list[[i]]
+  for (parset in parset_list) {
     learner$param_set$values = parset
 
     p = suppressWarnings(learner$train(task)$predict(task))
