@@ -20,8 +20,7 @@ test_that("Learner properties are respected", {
     list(k = 5, space = 5L, p = 5L, iterations = 5L)
   )
 
-  for (i in seq_along(parset_list)) {
-    parset = parset_list[[i]]
+  for (parset in parset_list) {
     learner$param_set$values = parset
 
     p = learner$train(task)$predict(task)
