@@ -19,8 +19,7 @@ test_that("Learner properties are respected", {
     list(threshold = 0.3, branching = 12L, maxLeaf = 5L, outlierThreshold = 0.3)
   )
 
-  for (i in seq_along(parset_list)) {
-    parset = parset_list[[i]]
+  for (parset in parset_list) {
     learner$param_set$values = parset
 
     p = learner$train(task)$predict(task)
