@@ -4,9 +4,9 @@ test_that("autotest", {
   learner = lrn("clust.meanshift")
   expect_learner(learner)
   task = generate_tasks(learner)
-  learner$train(task[[1]])
+  learner$train(task[[1L]])
   expect_class(learner$model, "ms")
-  expect_warning(learner$predict(task[[1]]), "doesn't predict on new data")
+  expect_warning(learner$predict(task[[1L]]), "doesn't predict on new data")
 })
 
 test_that("Learner properties are respected", {
@@ -21,8 +21,7 @@ test_that("Learner properties are respected", {
     list(thr = 0.1, iter = 100L)
   )
 
-  for (i in seq_along(parset_list)) {
-    parset = parset_list[[i]]
+  for (parset in parset_list) {
     learner$param_set$values = parset
 
     p = suppressWarnings(learner$train(task)$predict(task))
